@@ -1,6 +1,3 @@
-class BinUnitsModel;
-class Catalog;
-class Catalog;
 /* ****************************************************************************
   This file is part of Lokalize
 
@@ -24,8 +21,8 @@ class Catalog;
 
 **************************************************************************** */
 
-#ifndef BINUNITSWINDOW_H
-#define BINUNITSWINDOW_H
+#ifndef BINUNITSVIEW_H
+#define BINUNITSVIEW_H
 
 class Catalog;
 class BinUnitsModel;
@@ -39,15 +36,15 @@ class MyTreeView;
 
 class BinUnitsView: public QDockWidget
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    BinUnitsView(Catalog* catalog, QWidget *parent);
+    explicit BinUnitsView(Catalog* catalog, QWidget *parent);
 
 public slots:
     void selectUnit(const QString& id);
 
 private:
-    void contextMenuEvent(QContextMenuEvent *event);
+    void contextMenuEvent(QContextMenuEvent *event) override;
 private slots:
     void mouseDoubleClicked(const QModelIndex&);
     void fileLoaded();
@@ -61,23 +58,26 @@ private:
 
 class BinUnitsModel: public QAbstractListModel
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    enum BinUnitsModelColumns
-    {
-        SourceFilePath=0,
+    enum BinUnitsModelColumns {
+        SourceFilePath = 0,
         TargetFilePath,
         Approved,
         ColumnCount
     };
 
     BinUnitsModel(Catalog* catalog, QObject* parent);
-    ~BinUnitsModel(){}
+    ~BinUnitsModel() {}
 
-    int rowCount(const QModelIndex& parent=QModelIndex()) const;
-    int columnCount(const QModelIndex& parent=QModelIndex()) const{Q_UNUSED(parent); return ColumnCount;}
-    QVariant data(const QModelIndex&,int role=Qt::DisplayRole) const;
-    QVariant headerData(int section, Qt::Orientation, int role=Qt::DisplayRole) const;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override
+    {
+        Q_UNUSED(parent);
+        return ColumnCount;
+    }
+    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const override;
+    QVariant headerData(int section, Qt::Orientation, int role = Qt::DisplayRole) const override;
 
     void setTargetFilePath(int row, const QString&);
 
@@ -88,8 +88,8 @@ private slots:
 
 private:
     Catalog* m_catalog;
-    mutable QHash<QString,QImage> m_imageCache;
+    mutable QHash<QString, QImage> m_imageCache;
 
 };
 
-#endif // BINUNITSWINDOW_H
+#endif // BINUNITSVIEW_H
