@@ -3,8 +3,8 @@
   This file is based on the one from KBabel
 
   Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
-		2001-2004 by Stanislav Visnovsky <visnovsky@kde.org>
-		2007	  by Nick Shaforostoff <shafff@ukr.net>
+        2001-2004 by Stanislav Visnovsky <visnovsky@kde.org>
+        2007      by Nick Shaforostoff <shafff@ukr.net>
 
 
   This program is free software; you can redistribute it and/or modify
@@ -42,9 +42,7 @@
 #include "pos.h"
 #include "alttrans.h"
 
-#ifndef NOKDE
 #include <kautosavefile.h>
-#endif
 
 #include <QList>
 #include <QLinkedList>
@@ -76,9 +74,7 @@ public:
     int _numberOfPluralForms;
 
     QTimer _autoSaveTimer;
-#ifndef NOKDE
     KAutoSaveFile* _autoSave;
-#endif
     bool _autoSaveDirty;
     bool _autoSaveRecovered;
 
@@ -108,16 +104,14 @@ public:
     ProjectLocal::PersonRole _phaseRole;
 
     explicit CatalogPrivate(QObject* parent)
-           : fileCodec(0)
-           , _numberOfPluralForms(-1)
-#ifndef NOKDE
-           , _autoSave(new KAutoSaveFile(parent))
-#endif
-           , _autoSaveDirty(true)
-           , _autoSaveRecovered(false)
-           , _readOnly(false)
-           , _maxLineLength(80)
-           , _phaseRole(ProjectLocal::Undefined)
+        : fileCodec(0)
+        , _numberOfPluralForms(-1)
+        , _autoSave(new KAutoSaveFile(parent))
+        , _autoSaveDirty(true)
+        , _autoSaveRecovered(false)
+        , _readOnly(false)
+        , _maxLineLength(80)
+        , _phaseRole(ProjectLocal::Undefined)
     {
         Q_UNUSED(parent)
         _statesIndex.resize(StateCount);
