@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -24,13 +24,18 @@
 #ifndef CATALOGCAPABILITIES_H
 #define CATALOGCAPABILITIES_H
 
-enum CatalogCapabilities
-{
-    KeepsNoteAuthors=1,
-    MultipleNotes=2,
-    Phases=4,
-    ExtendedStates=8,
-    Tags=16
+enum CatalogCapabilities {
+    KeepsNoteAuthors = 1,
+    MultipleNotes = 2,
+    Phases = 4,
+    ExtendedStates = 8,
+    Tags = 16
+};
+
+enum CatalogType {
+    Gettext,
+    Xliff,
+    Ts
 };
 
 #endif
