@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -34,11 +34,10 @@
 #include "catalogstring.h"
 class Catalog;
 
-enum Commands
-{
+enum Commands {
     Insert, Delete,
     InsertTag, DeleteTag,
-    ToggleApprovement, EquivTrans, 
+    ToggleApprovement, EquivTrans,
     SetNote, UpdatePhase
 };
 
@@ -46,13 +45,16 @@ class LokalizeUnitCmd: public QUndoCommand
 {
 public:
     LokalizeUnitCmd(Catalog *catalog, const DocPosition& pos, const QString& name);
-    virtual ~LokalizeUnitCmd(){};
-    virtual void undo();
-    virtual void redo();
-    DocPosition pos()const{return _pos;}
+    ~LokalizeUnitCmd() override {}
+    void undo() override;
+    void redo() override;
+    DocPosition pos()const
+    {
+        return _pos;
+    }
 protected:
-    virtual void doRedo()=0;
-    virtual void doUndo()=0;
+    virtual void doRedo() = 0;
+    virtual void doUndo() = 0;
     /**
      * may be overridden to set customized pos
      * alternatively customized pos may be set manually in do*()
@@ -69,9 +71,9 @@ class LokalizeTargetCmd: public LokalizeUnitCmd
 {
 public:
     LokalizeTargetCmd(Catalog *catalog, const DocPosition& pos, const QString& name);
-    virtual ~LokalizeTargetCmd(){};
-    void undo();
-    void redo();
+    ~LokalizeTargetCmd() override {}
+    void undo() override;
+    void redo() override;
 protected:
     QString _prevTargetPhase;
 };
@@ -86,11 +88,14 @@ class InsTextCmd: public LokalizeTargetCmd
 {
 public:
     InsTextCmd(Catalog *catalog, const DocPosition& pos, const QString& str);
-    ~InsTextCmd(){};
-    int id () const {return Insert;}
-    bool mergeWith(const QUndoCommand *other);
-    void doRedo();
-    void doUndo();
+    ~InsTextCmd() override {}
+    int id() const override
+    {
+        return Insert;
+    }
+    bool mergeWith(const QUndoCommand *other) override;
+    void doRedo() override;
+    void doUndo() override;
 private:
     QString _str;
 };
@@ -100,11 +105,14 @@ class DelTextCmd: public LokalizeTargetCmd
 {
 public:
     DelTextCmd(Catalog *catalog, const DocPosition& pos, const QString& str);
-    ~DelTextCmd(){};
-    int id () const {return Delete;}
-    bool mergeWith(const QUndoCommand *other);
-    void doRedo();
-    void doUndo();
+    ~DelTextCmd() override {}
+    int id() const override
+    {
+        return Delete;
+    }
+    bool mergeWith(const QUndoCommand *other) override;
+    void doRedo() override;
+    void doUndo() override;
 private:
     QString _str;
 };
@@ -114,11 +122,14 @@ class SetStateCmd: public LokalizeUnitCmd
 private:
     SetStateCmd(Catalog *catalog, const DocPosition& pos, TargetState state);
 public:
-    ~SetStateCmd(){};
+    ~SetStateCmd() override {}
 
-    int id () const {return ToggleApprovement;}
-    void doRedo();
-    void doUndo();
+    int id() const override
+    {
+        return ToggleApprovement;
+    }
+    void doRedo() override;
+    void doUndo() override;
 
     static void push(Catalog *catalog, const DocPosition& pos, bool approved);
     static void instantiateAndPush(Catalog *catalog, const DocPosition& pos, TargetState state);
@@ -133,10 +144,13 @@ class InsTagCmd: public LokalizeTargetCmd
 public:
     /// offset is taken from @a tag and not from @a pos
     InsTagCmd(Catalog *catalog, const DocPosition& pos, const InlineTag& tag);
-    ~InsTagCmd(){};
-    int id () const {return InsertTag;}
-    void doRedo();
-    void doUndo();
+    ~InsTagCmd() override {}
+    int id() const override
+    {
+        return InsertTag;
+    }
+    void doRedo() override;
+    void doUndo() override;
 private:
     InlineTag _tag;
 };
@@ -150,11 +164,17 @@ class DelTagCmd: public LokalizeTargetCmd
 {
 public:
     DelTagCmd(Catalog *catalog, const DocPosition& pos);
-    ~DelTagCmd(){};
-    int id () const {return DeleteTag;}
-    void doRedo();
-    void doUndo();
-    InlineTag tag()const{return _tag;}//used to get proprties of deleted tag
+    ~DelTagCmd() override {}
+    int id() const override
+    {
+        return DeleteTag;
+    }
+    void doRedo() override;
+    void doUndo() override;
+    InlineTag tag()const
+    {
+        return _tag;   //used to get proprties of deleted tag
+    }
 private:
     InlineTag _tag;
 };
@@ -165,12 +185,15 @@ class SetNoteCmd: public LokalizeUnitCmd
 public:
     /// @a pos.form is note number
     SetNoteCmd(Catalog *catalog, const DocPosition& pos, const Note& note);
-    ~SetNoteCmd(){};
-    int id () const {return SetNote;}
+    ~SetNoteCmd() override {}
+    int id() const override
+    {
+        return SetNote;
+    }
 protected:
-    void doRedo();
-    void doUndo();
-    void setJumpingPos();
+    void doRedo() override;
+    void doUndo() override;
+    void setJumpingPos() override;
 private:
     Note _note;
     Note _prevNote;
@@ -182,10 +205,13 @@ class UpdatePhaseCmd: public QUndoCommand
 public:
     /// @a pos.form is note number
     UpdatePhaseCmd(Catalog *catalog, const Phase& phase);
-    ~UpdatePhaseCmd(){};
-    int id () const {return UpdatePhase;}
-    void redo();
-    void undo();
+    ~UpdatePhaseCmd() override {}
+    int id() const override
+    {
+        return UpdatePhase;
+    }
+    void redo() override;
+    void undo() override;
 private:
     Catalog* _catalog;
     Phase _phase;
@@ -197,10 +223,13 @@ class SetEquivTransCmd: public LokalizeTargetCmd
 {
 public:
     SetEquivTransCmd(Catalog *catalog, const DocPosition& pos, bool equivTrans);
-    ~SetEquivTransCmd(){};
-    int id () const {return EquivTrans;}
-    void doRedo();
-    void doUndo();
+    ~SetEquivTransCmd() override {}
+    int id() const override
+    {
+        return EquivTrans;
+    }
+    void doRedo() override;
+    void doUndo() override;
 private:
     bool _equivTrans;
 };
@@ -213,8 +242,8 @@ private:
  * 1 means this is start, 2 means this is end
  * @returns false if it can't find second part of any paired tag in the range
  */
-bool fillTagPlaces(QMap<int,int>& tagPlaces, const CatalogString& catalogString, int start, int len);
-bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart=0, int delLen=-1);
-void insertCatalogString(Catalog* catalog, DocPosition pos, const CatalogString& catStr, int start=0);
+bool fillTagPlaces(QMap<int, int>& tagPlaces, const CatalogString& catalogString, int start, int len);
+bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart = 0, int delLen = -1);
+void insertCatalogString(Catalog* catalog, DocPosition pos, const CatalogString& catStr, int start = 0);
 
 #endif // CMD_H
