@@ -60,16 +60,20 @@ class FileSearchTab: public LokalizeSubwindowBase2
     //qdbuscpp2xml -m -s filesearch/filesearchtab.h -o filesearch/org.kde.lokalize.FileSearch.xml
 
 public:
-    FileSearchTab(QWidget *parent);
-    ~FileSearchTab();
+    explicit FileSearchTab(QWidget *parent);
+    ~FileSearchTab() override;
 
-    void hideDocks(){};
-    void showDocks(){};
-#ifndef NOKDE
-    KXMLGUIClient* guiClient(){return (KXMLGUIClient*)this;}
+    void hideDocks() override {}
+    void showDocks() override {}
+    KXMLGUIClient* guiClient() override
+    {
+        return (KXMLGUIClient*)this;
+    }
     QString dbusObjectPath();
-    int dbusId(){return m_dbusId;}
-#endif
+    int dbusId()
+    {
+        return m_dbusId;
+    }
 
 public slots:
     void copySourceToClipboard();
@@ -79,10 +83,11 @@ public slots:
     Q_SCRIPTABLE void addFilesToSearch(const QStringList&);
     Q_SCRIPTABLE void setSourceQuery(const QString&);
     Q_SCRIPTABLE void setTargetQuery(const QString&);
-#ifndef NOKDE
-    Q_SCRIPTABLE bool findGuiText(QString text){return findGuiTextPackage(text,QString());}
+    Q_SCRIPTABLE bool findGuiText(QString text)
+    {
+        return findGuiTextPackage(text, QString());
+    }
     Q_SCRIPTABLE bool findGuiTextPackage(QString text, QString package);
-#endif
     void fileSearchNext();
     void stopSearch();
     void massReplace(const QRegExp &what, const QString& with);
@@ -92,12 +97,12 @@ private slots:
     void replaceJobDone(MassReplaceJob*);
 
 signals:
-    void fileOpenRequested(const QString& filePath, DocPosition docPos, int selection);
-    void fileOpenRequested(const QString& filePath);
+    void fileOpenRequested(const QString& filePath, DocPosition docPos, int selection, const bool setAsActive);
+    void fileOpenRequested(const QString& filePath, const bool setAsActive);
 
 private:
-    void dragEnterEvent(QDragEnterEvent* event);
-    void dropEvent(QDropEvent*);
+    void dragEnterEvent(QDragEnterEvent* event) override;
+    void dropEvent(QDropEvent*) override;
 
 
 private:
@@ -111,15 +116,14 @@ private:
 
     QVector<QRunnable*> m_runningJobs;
 
-     //to avoid results from previous search showing up in the new one
+    //to avoid results from previous search showing up in the new one
     int m_lastSearchNumber;
 
     int m_dbusId;
     static QList<int> ids;
 };
 
-struct FileSearchResult
-{
+struct FileSearchResult {
     DocPos docPos;
 
     QString source;
@@ -139,12 +143,11 @@ struct FileSearchResult
 
 typedef QMap<QString, QVector<FileSearchResult> > FileSearchResults;
 
-struct SearchResult: public FileSearchResult
-{
+struct SearchResult: public FileSearchResult {
     QString filepath;
 
-    SearchResult(const FileSearchResult& fsr):FileSearchResult(fsr){}
-    SearchResult(){}
+    SearchResult(const FileSearchResult& fsr): FileSearchResult(fsr) {}
+    SearchResult() {}
 };
 
 typedef QVector<SearchResult> SearchResults;
@@ -154,9 +157,8 @@ class FileSearchModel: public QAbstractListModel
     Q_OBJECT
 public:
 
-    enum FileSearchModelColumns
-    {
-        Source=0,
+    enum FileSearchModelColumns {
+        Source = 0,
         Target,
         //Context,
         Filepath,
@@ -165,23 +167,34 @@ public:
         ColumnCount
     };
 
-    enum Roles
-    {
-        FullPathRole=Qt::UserRole,
-        TransStateRole=Qt::UserRole+1,
-        HtmlDisplayRole=Qt::UserRole+2
+    enum Roles {
+        FullPathRole = Qt::UserRole,
+        TransStateRole = Qt::UserRole + 1,
+        HtmlDisplayRole = Qt::UserRole + 2
     };
 
-    FileSearchModel(QObject* parent);
-    ~FileSearchModel(){}
+    explicit FileSearchModel(QObject* parent);
+    ~FileSearchModel() override {}
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-    QVariant data(const QModelIndex& item, int role=Qt::DisplayRole) const;
-    int columnCount(const QModelIndex& parent=QModelIndex()) const {Q_UNUSED(parent) return ColumnCount;}
-    int rowCount(const QModelIndex& parent = QModelIndex()) const {Q_UNUSED(parent) return m_searchResults.size();}
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    QVariant data(const QModelIndex& item, int role = Qt::DisplayRole) const override;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override
+    {
+        Q_UNUSED(parent) return ColumnCount;
+    }
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override
+    {
+        Q_UNUSED(parent) return m_searchResults.size();
+    }
 
-    SearchResults searchResults()const {return m_searchResults;}
-    SearchResult searchResult(const QModelIndex& item) const {return m_searchResults.at(item.row());}
+    SearchResults searchResults()const
+    {
+        return m_searchResults;
+    }
+    SearchResult searchResult(const QModelIndex& item) const
+    {
+        return m_searchResults.at(item.row());
+    }
     void appendSearchResults(const SearchResults&);
     void clear();
 
@@ -199,21 +212,21 @@ class SearchFileListView: public QDockWidget
     Q_OBJECT
 
 public:
-    SearchFileListView(QWidget*);
-    ~SearchFileListView(){}
+    explicit SearchFileListView(QWidget*);
+    ~SearchFileListView() {}
 
     void addFiles(const QStringList& files);
     void addFilesFast(const QStringList& files);
 
     QStringList files()const;
 
-    void scrollTo(const QString& file=QString());
+    void scrollTo(const QString& file = QString());
 
 public slots:
     void clear();
     void requestFileOpen(const QModelIndex&);
 signals:
-    void fileOpenRequested(const QString& filePath);
+    void fileOpenRequested(const QString& filePath, const bool setAsActive);
 
 private:
     QTreeView* m_browser;
@@ -228,7 +241,7 @@ class MassReplaceView: public QDockWidget
     Q_OBJECT
 
 public:
-    MassReplaceView(QWidget*);
+    explicit MassReplaceView(QWidget*);
     ~MassReplaceView();
 
     void deactivatePreview();
@@ -246,8 +259,7 @@ private:
     Ui_MassReplaceOptions* ui;
 };
 
-struct SearchParams
-{
+struct SearchParams {
     QRegExp sourcePattern;
     QRegExp targetPattern;
     QRegExp notesPattern;
@@ -259,7 +271,10 @@ struct SearchParams
 
     bool isEmpty() const;
 
-    SearchParams():invertSource(false), invertTarget(false){memset(states, 0, sizeof(states));}
+    SearchParams(): invertSource(false), invertTarget(false)
+    {
+        memset(states, 0, sizeof(states));
+    }
 };
 
 #include <QRunnable>
@@ -267,17 +282,17 @@ class SearchJob: public QObject, public QRunnable
 {
     Q_OBJECT
 public:
-    explicit SearchJob(const QStringList& f, 
+    explicit SearchJob(const QStringList& f,
                        const SearchParams& sp,
                        const QVector<Rule>& r,
                        int sn,
-                       QObject* parent=0);
-    ~SearchJob(){}
+                       QObject* parent = nullptr);
+    ~SearchJob() override {}
 
 signals:
     void done(SearchJob*);
 protected:
-    void run ();
+    void run() override;
 public:
     QStringList files;
     SearchParams searchParams;
@@ -299,14 +314,14 @@ public:
                             const QRegExp& s,
                             const QString& r,
                             //int sn,
-                           QObject* parent=0);
-    ~MassReplaceJob(){}
+                            QObject* parent = nullptr);
+    ~MassReplaceJob() override {}
 
 signals:
     void done(MassReplaceJob*);
 
 protected:
-    void run();
+    void run() override;
 public:
     SearchResults searchResults;
     int globalPos;
