@@ -10,7 +10,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -39,8 +39,8 @@ class QTimer;
 class QThreadPool;
 class UpdateStatsJob;
 
-struct FileMetaData
-{
+struct FileMetaData {
+    bool invalid_file;
     int translated;
     int translated_reviewer;
     int translated_approver;
@@ -56,8 +56,8 @@ struct FileMetaData
     QString filePath;
 
     FileMetaData()
-     : translated(0), translated_reviewer(0), translated_approver(0), untranslated(0)
-     , fuzzy(0), fuzzy_reviewer(0), fuzzy_approver(0)
+        : invalid_file(false), translated(0), translated_reviewer(0), translated_approver(0), untranslated(0)
+        , fuzzy(0), fuzzy_reviewer(0), fuzzy_approver(0)
     {}
 };
 
@@ -83,33 +83,31 @@ class ProjectModel: public QAbstractItemModel
         ~ProjectNode();
         void calculateDirStats();
         void setFileStats(const FileMetaData& info);
-        
+
         int translatedAsPerRole() const
         {
-            switch (Project::local()->role())
-            {
-                case ProjectLocal::Translator:
-                case ProjectLocal::Undefined:
-                    return translated;
-                case ProjectLocal::Reviewer:
-                    return translated_reviewer;
-                case ProjectLocal::Approver:
-                    return translated_approver;
+            switch (Project::local()->role()) {
+            case ProjectLocal::Translator:
+            case ProjectLocal::Undefined:
+                return translated;
+            case ProjectLocal::Reviewer:
+                return translated_reviewer;
+            case ProjectLocal::Approver:
+                return translated_approver;
             }
             return -1;
         }
-        
+
         int fuzzyAsPerRole() const
         {
-            switch (Project::local()->role())
-            {
-                case ProjectLocal::Translator:
-                case ProjectLocal::Undefined:
-                    return fuzzy;
-                case ProjectLocal::Reviewer:
-                    return fuzzy_reviewer;
-                case ProjectLocal::Approver:
-                    return fuzzy_approver;
+            switch (Project::local()->role()) {
+            case ProjectLocal::Translator:
+            case ProjectLocal::Undefined:
+                return fuzzy;
+            case ProjectLocal::Reviewer:
+                return fuzzy_reviewer;
+            case ProjectLocal::Approver:
+                return fuzzy_approver;
             }
             return -1;
         }
@@ -123,6 +121,7 @@ class ProjectModel: public QAbstractItemModel
         short poCount; //number of items from PO in rows. The others will be form POT exclusively.
         QVector<ProjectNode*> rows; //rows from po and pot, pot rows start from poCount;
 
+        bool invalid_file;
         int translated;
         int translated_reviewer;
         int translated_approver;
@@ -138,8 +137,7 @@ class ProjectModel: public QAbstractItemModel
 
 public:
 
-    enum ProjectModelColumns
-    {
+    enum ProjectModelColumns {
         FileName,
         Graph,
         TotalCount,
@@ -155,15 +153,17 @@ public:
 
     enum AdditionalRoles {
         FuzzyUntrCountRole = Qt::UserRole,
+        FuzzyUntrCountAllRole,
         FuzzyCountRole,
         UntransCountRole,
         TemplateOnlyRole,
         TransOnlyRole,
+        DirectoryRole,
         TotalRole
     };
 
-    ProjectModel(QObject *parent);
-    ~ProjectModel();
+    explicit ProjectModel(QObject *parent);
+    ~ProjectModel() override;
 
     void setUrl(const QUrl &poUrl, const QUrl &potUrl);
     QModelIndex indexForUrl(const QUrl& url);
@@ -171,22 +171,28 @@ public:
     QUrl beginEditing(const QModelIndex& index); //copies POT file to PO file and returns url of the PO file
 
     // QAbstractItemModel methods
-    int columnCount(const QModelIndex& parent = QModelIndex()) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-    Qt::ItemFlags flags(const QModelIndex& index) const;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
 
-    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex& index) const ;
+    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex& index) const  override;
 
-    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-    int rowCount(const QModelIndex& parent = QModelIndex()) const;
-    bool hasChildren(const QModelIndex& parent = QModelIndex()) const;
+    QVariant data(const QModelIndex& index, const int role = Qt::DisplayRole) const override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    bool hasChildren(const QModelIndex& parent = QModelIndex()) const override;
 
-    bool canFetchMore(const QModelIndex& parent) const;
-    void fetchMore(const QModelIndex& parent);
+    bool canFetchMore(const QModelIndex& parent) const override;
+    void fetchMore(const QModelIndex& parent) override;
 
-    QThreadPool* threadPool(){return m_threadPool;}
-    void setCompleteScan(bool enable){m_completeScan=enable;}
+    QThreadPool* threadPool()
+    {
+        return m_threadPool;
+    }
+    void setCompleteScan(bool enable)
+    {
+        m_completeScan = enable;
+    }
 
 signals:
     void totalsChanged(int fuzzy, int translated, int untranslated, bool done);
@@ -245,7 +251,9 @@ private:
 
     QVariant m_dirIcon;
     QVariant m_poIcon;
+    QVariant m_poInvalidIcon;
     QVariant m_poComplIcon;
+    QVariant m_poEmptyIcon;
     QVariant m_potIcon;
 
     //for updating stats
@@ -266,9 +274,12 @@ class UpdateStatsJob: public QObject, public QRunnable
 {
     Q_OBJECT
 public:
-    explicit UpdateStatsJob(QList<KFileItem> files, QObject* owner=0);
-    ~UpdateStatsJob();
-    int priority()const{return 35;} //SEE jobs.h
+    explicit UpdateStatsJob(const QList<KFileItem> &files, QObject* owner = nullptr);
+    ~UpdateStatsJob() override;
+    int priority()const
+    {
+        return 35;   //SEE jobs.h
+    }
 
     void setStatus(int status);
 
@@ -277,7 +288,7 @@ public:
     volatile int m_status; // 0 = running; -1 = cancel; -2 = abort
 
 protected:
-    void run();
+    void run() override;
 
 signals:
     void done(UpdateStatsJob*);
