@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -30,41 +30,40 @@
 #include <QTime>
 #include <QVector>
 
-#ifndef NOKDE
 #include <kjob.h>
-#endif
 
 bool dragIsAcceptable(const QList<QUrl>& urls);
 QString shorterFilePath(const QString path);
 
 
-namespace TM {
+namespace TM
+{
 class ScanJob;
 class ScanJobFeedingBack;
 
+void purgeMissingFilesFromTM(const QStringList& urls, const QString& dbName);
+
 ///wrapper. returns gross number of jobs started
 int scanRecursive(const QStringList& urls, const QString& dbName);
 
-#ifndef NOKDE
 class RecursiveScanJob: public KJob
 {
     Q_OBJECT
 public:
-    RecursiveScanJob(const QString& dbName,QObject* parent=0);
+    explicit RecursiveScanJob(const QString& dbName, QObject* parent = nullptr);
     void setJobs(const QVector<ScanJob*>& jobs);
-    void start();
+    void start() override;
 
 public slots:
     void scanJobFinished(ScanJobFeedingBack*);
 protected:
-    bool doKill();
+    bool doKill() override;
 
 private:
     QString m_dbName;
     QTime m_time;
     QVector<ScanJob*> m_jobs;
 };
-#endif
 }
 
 #endif
